@@ -1,5 +1,6 @@
 //! BAM record and fields.
 
+pub mod builder;
 pub mod cigar;
 mod convert;
 pub mod data;
@@ -8,7 +9,7 @@ pub mod reference_sequence_id;
 pub mod sequence;
 
 pub use self::{
-    cigar::Cigar, data::Data, quality_scores::QualityScores,
+    builder::Builder, cigar::Cigar, data::Data, quality_scores::QualityScores,
     reference_sequence_id::ReferenceSequenceId, sequence::Sequence,
 };
 
@@ -47,12 +48,12 @@ pub(crate) const UNMAPPED_POSITION: i32 = -1;
 /// them.
 #[derive(Clone, Eq, PartialEq)]
 pub struct Record {
-    pub(crate) ref_id: i32,
+    ref_id: Option<ReferenceSequenceId>,
     pub(crate) pos: i32,
     mapq: sam::record::MappingQuality,
     bin: u16,
     flag: sam::record::Flags,
-    pub(crate) next_ref_id: i32,
+    next_ref_id: Option<ReferenceSequenceId>,
     pub(crate) next_pos: i32,
     tlen: i32,
     pub(crate) read_name: Vec<u8>,
@@ -63,6 +64,20 @@ pub struct Record {
 }
 
 impl Record {
+    /// Creates a BAM record builder.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bam as bam;
+    /// let builder = bam::Record::builder();
+    /// let record = builder.build()?;
+    /// # Ok::<(), bam::record::builder::BuildError>(())
+    /// ```
+    pub fn builder() -> Builder {
+        Builder::default()
+    }
+
     pub(crate) fn block_size(&self) -> usize {
         mem::size_of::<i32>() // ref_id
             + mem::size_of::<i32>() // pos
@@ -95,13 +110,24 @@ impl Record {
     /// assert!(record.reference_sequence_id().is_none());
     /// ```
     pub fn reference_sequence_id(&self) -> Option<ReferenceSequenceId> {
-        let id = self.ref_id;
+        self.ref_id
+    }
 
-        if id == reference_sequence_id::UNMAPPED {
-            None
-        } else {
-            ReferenceSequenceId::try_from(id).ok()
-        }
+    /// Returns a mutable reference to the reference sequence ID.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bam::{self as bam, record::ReferenceSequenceId};
+    ///
+    /// let mut record = bam::Record::default();
+    /// *record.reference_sequence_id_mut() = ReferenceSequenceId::try_from(1).map(Some)?;
+    ///
+    /// assert_eq!(record.reference_sequence_id().map(i32::from), Some(1));
+    /// # Ok::<_, bam::record::reference_sequence_id::TryFromIntError>(())
+    /// ```
+    pub fn reference_sequence_id_mut(&mut self) -> &mut Option<ReferenceSequenceId> {
+        &mut self.ref_id
     }
 
     /// Returns the start position of this record.
@@ -215,13 +241,24 @@ impl Record {
     /// assert!(record.mate_reference_sequence_id().is_none());
     /// ```
     pub fn mate_reference_sequence_id(&self) -> Option<ReferenceSequenceId> {
-        let id = self.next_ref_id;
+        self.next_ref_id
+    }
 
-        if id == reference_sequence_id::UNMAPPED {
-            None
-        } else {
-            ReferenceSequenceId::try_from(id).ok()
-        }
+    /// Returns a mutable reference to the mate reference sequence ID.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bam::{self as bam, record::ReferenceSequenceId};
+    ///
+    /// let mut record = bam::Record::default();
+    /// *record.mate_reference_sequence_id_mut() = ReferenceSequenceId::try_from(1).map(Some)?;
+    ///
+    /// assert_eq!(record.mate_reference_sequence_id().map(i32::from), Some(1));
+    /// # Ok::<_, bam::record::reference_sequence_id::TryFromIntError>(())
+    /// ```
+    pub fn mate_reference_sequence_id_mut(&mut self) -> &mut Option<ReferenceSequenceId> {
+        &mut self.next_ref_id
     }
 
     /// Returns the start position of the mate of this record.
@@ -507,12 +544,12 @@ impl Default for Record {
         use sam::record::{Flags, MappingQuality};
 
         Self {
-            ref_id: reference_sequence_id::UNMAPPED,
+            ref_id: None,
             pos: UNMAPPED_POSITION,
             mapq: MappingQuality::default(),
             bin: 4680,
             flag: Flags::UNMAPPED,
-            next_ref_id: reference_sequence_id::UNMAPPED,
+            next_ref_id: None,
             next_pos: UNMAPPED_POSITION,
             tlen: 0,
             read_name: b"*\x00".to_vec(),
@@ -553,13 +590,17 @@ mod tests {
     fn build_record() -> io::Result<Record> {
         use sam::record::{Flags, MappingQuality};
 
+        let ref_id = ReferenceSequenceId::try_from(10)
+            .map(Some)
+            .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
+
         Ok(Record {
-            ref_id: 10,
+            ref_id,
             pos: 61061,
             mapq: MappingQuality::from(12),
             bin: 4684,
             flag: Flags::PAIRED | Flags::READ_1,
-            next_ref_id: 10,
+            next_ref_id: ref_id,
             next_pos: 61152,
             tlen: 166,
             read_name: b"r0\x00".to_vec(),
