@@ -20,7 +20,7 @@ use crate::record::sequence::Base;
 const BLOCK_HEADER_SIZE: u32 = 32;
 
 // § 4.2.3 SEQ and QUAL encoding (2021-06-03)
-const NULL_QUALITY_SCORE: u8 = 255;
+pub(crate) const NULL_QUALITY_SCORE: u8 = 255;
 
 pub fn write_sam_record<W>(
     writer: &mut W,
@@ -102,25 +102,23 @@ where
     let sequence = record.sequence();
     let quality_scores = record.quality_scores();
 
-    if !sequence.is_empty() {
-        write_seq(writer, sequence)?;
+    write_seq(writer, sequence)?;
 
-        if sequence.len() == quality_scores.len() {
-            write_qual(writer, quality_scores)?;
-        } else if quality_scores.is_empty() {
-            for _ in 0..sequence.len() {
-                writer.write_u8(NULL_QUALITY_SCORE)?;
-            }
-        } else {
-            return Err(io::Error::new(
-                io::ErrorKind::InvalidInput,
-                format!(
-                    "quality scores length mismatch: expected {}, got {}",
-                    sequence.len(),
-                    quality_scores.len()
-                ),
-            ));
+    if sequence.len() == quality_scores.len() {
+        write_qual(writer, quality_scores)?;
+    } else if quality_scores.is_empty() {
+        for _ in 0..sequence.len() {
+            writer.write_u8(NULL_QUALITY_SCORE)?;
         }
+    } else {
+        return Err(io::Error::new(
+            io::ErrorKind::InvalidInput,
+            format!(
+                "quality scores length mismatch: expected {}, got {}",
+                sequence.len(),
+                quality_scores.len()
+            ),
+        ));
     }
 
     write_data(writer, record.data())?;
